module Ansei
  # File information for Ansei
  class FileInfo
    attr_reader :file, :type

    # Initialize a new FileInfo object
    #
    # type - 'standardized' type of file
    # file - filename for file
    #
    # Returns a new FileInfo object
    def initialize(type, file)
      @type = type
      @file = file
    end

    # Get the file's build directory
    #
    # Returns a string
    def build
      Ansei.config[:directories][type].last
    end

    # Get the file's destination filename
    #
    # Returns a string
    def destination
      dir = Ansei.config[:directories][:build]

      "#{dir}/#{name}"
    end

    # Get the file's extension
    #
    # Returns a string
    def ext
      Utils.file_ext(file, true)
    end

    # Get the destination file extension, and all
    # other possible extensions for its type
    #
    # Returns an array
    def exts
      Ansei.config[:extensions][type]
    end

    # Get the 'basename' for the file
    #
    # Returns a string
    def name
      name = file.sub("#{source}/", '')
      name = name.sub(Utils.file_ext(file), '')

      name = Utils.string_urlify(name) if type == :markdown
      name = "#{build}/#{name}.#{exts.first}"

      name.sub(/\A\//, '')
    end

    # Get the file's source directory
    #
    # Returns a string
    def source
      Ansei.config[:directories][type].first
    end
  end
end
