module Ansei
  # Rendering class for Ansei
  class Render
    attr_accessor :original
    attr_reader :info

    # Initialize a new Render object
    #
    # info - FileInformation object
    def initialize(info)
      @info = info

      @original = File.read(info.file)
    end

    # Compile the objects content and
    # write that to its destination
    def compile
      Utils.cli_log("    create  #{info.name}")

      type = info.type == :markdown ? info.type : :asset
      body = method(type).call

      Utils.file_write(info.destination, body)
    end

    protected

    # Compile as an asset
    #
    # Returns the compiled string
    def asset
      return original if info.ext == info.exts.first

      tilt(info.ext)
    end

    # Compile as Markdown
    #
    # Returns the compiled string
    def markdown
      parts = original.match Ansei.config[:regex][:markdown]

      @original = parts[:body]

      markdown = tilt('md')
      metadata = Utils.string_to_yaml(parts[:yaml])

      template(metadata, markdown)
    end

    # Compile as a template
    #
    # metadata - frontmatter YAML
    # markdown - compiled Markdown
    #
    # Returns the compiled string
    def template(metadata, markdown)
      template = metadata.layout
      filename = "#{Ansei.config[:directories][:templates].first}/#{template}"

      return markdown if template.nil? || File.exist?(filename) == false

      @original = File.read(filename)

      tilt('erb', metadata, markdown)
    end

    # "Wrapper" for Tilt
    #
    # type      - type of rendering
    # metadata  - optional (local) variables
    # yieldable - object to use with 'yield'
    #
    # Returns the compiled string
    def tilt(type, metadata = nil, yieldable = nil)
      compiled = Tilt[type].new { original }

      return compiled.render if metadata.nil? && yieldable.nil?

      compiled.render(metadata) { yieldable }
    end
  end
end
