module Ansei
  # Build class for Ansei
  class Shehai
    # Build and compile a site from source files
    def build
      clean_build_directory

      compile(:javascript)
      compile(:stylesheets)
      compile(:markdown)
    end

    protected

    # Compile assets of a certain type
    #
    # type - key for information lookup
    def compile(type)
      dir = Ansei.config[:directories][type].first
      ext = Ansei.config[:extensions][type].first

      Utils.cli_log("  #{ext}:")

      Utils.dir_glob(dir).each do |file|
        compile_asset(type, file)
      end
    end

    # Compile a single asset of a certain type
    #
    # type - key for information lookup
    # file - filename for asset
    def compile_asset(type, file)
      info = Utils.file_info(type, file)

      return unless info.ext == info.exts.first ||
                    info.exts.last.include?(info.ext)

      Render.new(info).compile
    end

    # Clean out the build directory
    def clean_build_directory
      Utils.dir_empty(Ansei.config[:directories][:build])
    end
  end
end
